.. kooplearn documentation master file, created by
   sphinx-quickstart on Sat Jan 14 15:52:00 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Kooplearn's documentation.
=====================================

.. toctree::
   :maxdepth: 2
   :caption: About Kooplearn
   
   getting_started
   

.. toctree::
   :maxdepth: 2
   :caption: API reference

   api/kooplearn.estimators
   api/kooplearn.kernels
   api/kooplearn.utils


